pub enum CoreError {
InvalidBech32(String),
InvalidAddressLength(usize),
EmptyAddress,
InvalidMnemonic(String),
InvalidPrivateKey(String),
WalletCreation(String),
InvalidNumeric(String),
InvalidBigIntEncoding(String),
InvalidBase64(String),
InvalidHex(String),
Bech32Encode(String),
InvalidHrp(String),
}Expand description
Errors returned by mx-core public functions.
Variants
InvalidBech32(String)
The input is not a valid bech32 string.
InvalidAddressLength(usize)
Decoded address does not have the expected byte length.
EmptyAddress
Address byte slice is empty.
InvalidMnemonic(String)
BIP39 mnemonic is invalid.
InvalidPrivateKey(String)
A private key derivation step failed.
WalletCreation(String)
Wallet creation from a derived private key failed.
InvalidNumeric(String)
A numeric value could not be parsed.
InvalidBigIntEncoding(String)
A protobuf big integer field does not use the expected Go BigIntCaster encoding.
InvalidBase64(String)
Base64 decoding failed.
InvalidHex(String)
Hex decoding failed.
Bech32Encode(String)
Bech32 encoding failed.
InvalidHrp(String)
HRP (human-readable part) parsing failed during bech32 encoding.